package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;

public class DistributionPoint extends ASN1Encodable {
   DistributionPointName distributionPoint;
   ReasonFlags reasons;
   GeneralNames cRLIssuer;

   public static DistributionPoint getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static DistributionPoint getInstance(Object obj) {
      if (obj != null && !(obj instanceof DistributionPoint)) {
         if (obj instanceof ASN1Sequence) {
            return new DistributionPoint((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("Invalid DistributionPoint: " + obj.getClass().getName());
         }
      } else {
         return (DistributionPoint)obj;
      }
   }

   public DistributionPoint(ASN1Sequence seq) {
      for(int var2 = 0; var2 != seq.size(); ++var2) {
         ASN1TaggedObject var3;
         int var4;
         if ((var4 = (var3 = ASN1TaggedObject.getInstance(seq.getObjectAt(var2))).getTagNo()) != 0) {
            if (var4 != 1) {
               if (var4 == 2) {
                  this.cRLIssuer = GeneralNames.getInstance(var3, false);
               }
            } else {
               this.reasons = new ReasonFlags(DERBitString.getInstance(var3, false));
            }
         } else {
            this.distributionPoint = DistributionPointName.getInstance(var3, true);
         }
      }

   }

   public DistributionPoint(DistributionPointName distributionPoint, ReasonFlags reasons, GeneralNames cRLIssuer) {
      this.distributionPoint = distributionPoint;
      this.reasons = reasons;
      this.cRLIssuer = cRLIssuer;
   }

   private void appendObject(StringBuffer buf, String sep, String name, String value) {
      buf.append("    ");
      buf.append(name);
      buf.append(":");
      buf.append(sep);
      buf.append("    ");
      buf.append("    ");
      buf.append(value);
      buf.append(sep);
   }

   public DistributionPointName getDistributionPoint() {
      return this.distributionPoint;
   }

   public ReasonFlags getReasons() {
      return this.reasons;
   }

   public GeneralNames getCRLIssuer() {
      return this.cRLIssuer;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      DistributionPointName var2;
      DERTaggedObject var3;
      if ((var2 = this.distributionPoint) != null) {
         var3 = new DERTaggedObject.<init>(0, var2);
         var1.add(var3);
      }

      ReasonFlags var5;
      if ((var5 = this.reasons) != null) {
         var3 = new DERTaggedObject.<init>(false, 1, var5);
         var1.add(var3);
      }

      GeneralNames var4;
      if ((var4 = this.cRLIssuer) != null) {
         DERTaggedObject var6;
         var6 = new DERTaggedObject.<init>(false, 2, var4);
         var1.add(var6);
      }

      return new DERSequence(var1);
   }

   public String toString() {
      String var1 = System.getProperty("line.separator");
      StringBuffer var2;
      StringBuffer var10001 = var2 = new StringBuffer;
      var10001.<init>();
      var10001.append("DistributionPoint: [");
      var10001.append(var1);
      DistributionPointName var3;
      String var5;
      if ((var3 = this.distributionPoint) != null) {
         var5 = var3.toString();
         this.appendObject(var2, var1, "distributionPoint", var5);
      }

      ReasonFlags var6;
      if ((var6 = this.reasons) != null) {
         var5 = var6.toString();
         this.appendObject(var2, var1, "reasons", var5);
      }

      GeneralNames var7;
      if ((var7 = this.cRLIssuer) != null) {
         DistributionPoint var10000 = this;
         String var4 = var7.toString();
         var10000.appendObject(var2, var1, "cRLIssuer", var4);
      }

      var2.append("]");
      var2.append(var1);
      return var2.toString();
   }
}
